@@ -1,26 +1,18 @@
-from pitop.pulse import configuration
-
-from pitopcommon.logger import PTLogger
-
-from binascii import (
-    hexlify,
-    unhexlify
-)
-from tempfile import mkstemp
-from os import (
-    close,
-    path,
-    remove,
-    rename,
-    stat,
-)
-import serial
+import logging
 import signal
+from binascii import hexlify, unhexlify
+from os import close, path, remove, rename, stat
 from struct import pack
 from sys import exit
+from tempfile import mkstemp
 from threading import Thread
 from time import sleep
 
+import serial
+
+from pitop.pulse import configuration
+
+logger = logging.getLogger(__name__)
 
 _bitrate = 8
 _continue_writing = False
@@ -48,7 +40,7 @@ def __signal_handler(signal, frame):
         if _thread_running is True:
             stop()
 
-    PTLogger.info("\nQuitting...")
+    logger.info("\nQuitting...")
     exit(0)
 
 
@@ -78,20 +70,20 @@ def __space_separated_little_endian(integer_value, byte_len):
     """
 
     if byte_len <= 1:
-        pack_type = '<B'
+        pack_type = "<B"
     elif byte_len <= 2:
-        pack_type = '<H'
+        pack_type = "<H"
     elif byte_len <= 4:
-        pack_type = '<I'
+        pack_type = "<I"
     elif byte_len <= 8:
-        pack_type = '<Q'
+        pack_type = "<Q"
     else:
-        PTLogger.info("Value cannot be represented in 8 bytes - exiting")
+        logger.info("Value cannot be represented in 8 bytes - exiting")
         exit()
 
     hex_string = pack(pack_type, integer_value)
     temp = hexlify(hex_string).decode()
-    return ' '.join([temp[i:i + 2] for i in range(0, len(temp), 2)])
+    return " ".join([temp[i : i + 2] for i in range(0, len(temp), 2)])
 
 
 def __init_header_information():
@@ -122,8 +114,7 @@ def __init_header_information():
     header += __from_hex(__space_separated_little_endian(16, 4))
     # AudioFormat   (PCM = 1)
     header += __from_hex(__space_separated_little_endian(1, 2))
-    header += __from_hex(__space_separated_little_endian(1, 2)
-                         )                   # NumChannels
+    header += __from_hex(__space_separated_little_endian(1, 2))  # NumChannels
     # SampleRate
     header += __from_hex(__space_separated_little_endian(capture_sample_rate, 4))
     # ByteRate (Same as SampleRate due to 1 channel, 1 byte per sample)
@@ -147,7 +138,7 @@ def __update_header_in_file(file, position, value):
     """
 
     hex_value = __space_separated_little_endian(value, 4)
-    data = unhexlify(''.join(hex_value.split()))
+    data = unhexlify("".join(hex_value.split()))
 
     file.seek(position)
     file.write(data)
@@ -162,12 +153,12 @@ def __finalise_wav_file(file_path):
     size_of_data = __get_size(file_path) - 44
 
     if size_of_data <= 0:
-        PTLogger.info("Error: No data was recorded!")
+        logger.info("Error: No data was recorded!")
         remove(file_path)
     else:
-        with open(file_path, 'rb+') as file:
+        with open(file_path, "rb+") as file:
 
-            PTLogger.debug("Updating header information...")
+            logger.debug("Updating header information...")
 
             __update_header_in_file(file, 4, size_of_data + 36)
             __update_header_in_file(file, 40, size_of_data)
@@ -194,37 +185,41 @@ def __record_audio():
     close(temp_file_tuple[0])
     _temp_file_path = temp_file_tuple[1]
 
-    if path.exists('/dev/serial0'):
+    if path.exists("/dev/serial0"):
 
-        PTLogger.debug("Opening serial device...")
+        logger.debug("Opening serial device...")
 
-        serial_device = serial.Serial(port='/dev/serial0', timeout=1, baudrate=250000,
-                                      parity=serial.PARITY_NONE, stopbits=serial.STOPBITS_ONE, bytesize=serial.EIGHTBITS)
+        serial_device = serial.Serial(
+            port="/dev/serial0",
+            timeout=1,
+            baudrate=250000,
+            parity=serial.PARITY_NONE,
+            stopbits=serial.STOPBITS_ONE,
+            bytesize=serial.EIGHTBITS,
+        )
         serial_device_open = serial_device.isOpen()
 
         if serial_device_open is True:
 
             try:
-                PTLogger.debug("Start recording")
+                logger.debug("Start recording")
 
-                with open(_temp_file_path, 'wb') as file:
+                with open(_temp_file_path, "wb") as file:
 
-                    PTLogger.debug("WRITING: initial header information")
+                    logger.debug("WRITING: initial header information")
                     file.write(__init_header_information())
 
                     if serial_device.inWaiting():
-                        PTLogger.debug(
-                            "Flushing input and starting from scratch")
+                        logger.debug("Flushing input and starting from scratch")
                         serial_device.flushInput()
 
-                    PTLogger.debug("WRITING: wave data")
+                    logger.debug("WRITING: wave data")
 
                     while _continue_writing:
                         while not serial_device.inWaiting():
                             sleep(0.01)
 
-                        audio_output = serial_device.read(
-                            serial_device.inWaiting())
+                        audio_output = serial_device.read(serial_device.inWaiting())
                         bytes_to_write = bytearray()
 
                         for pcm_data_block in audio_output:
@@ -235,13 +230,15 @@ def __record_audio():
                                 pcm_data_int = pcm_data_block
                                 scaled_val = int((pcm_data_int * 32768) / 255)
                                 bytes_to_write += __from_hex(
-                                    __space_separated_little_endian(scaled_val, 2))
+                                    __space_separated_little_endian(scaled_val, 2)
+                                )
 
                             else:
 
                                 pcm_data_int = pcm_data_block
                                 bytes_to_write += __from_hex(
-                                    __space_separated_little_endian(pcm_data_int, 1))
+                                    __space_separated_little_endian(pcm_data_int, 1)
+                                )
 
                         file.write(bytes_to_write)
 
@@ -252,20 +249,20 @@ def __record_audio():
 
                 __finalise_wav_file(_temp_file_path)
 
-                PTLogger.debug("Finished Recording.")
+                logger.debug("Finished Recording.")
 
         else:
-            PTLogger.info("Error: Serial port failed to open")
+            logger.info("Error: Serial port failed to open")
 
     else:
-        PTLogger.info(
-            "Error: Could not find serial port - are you sure it's enabled?")
+        logger.info("Error: Could not find serial port - are you sure it's enabled?")
 
 
 #######################
 # EXTERNAL OPERATIONS #
 #######################
 
+
 def record():
     """Start recording on the pi-topPULSE microphone."""
 
@@ -274,7 +271,7 @@ def record():
     global _recording_thread
 
     if not configuration.mcu_enabled():
-        PTLogger.info("Error: pi-topPULSE is not initialised.")
+        logger.info("Error: pi-topPULSE is not initialised.")
         exit()
 
     if _thread_running is False:
@@ -283,7 +280,7 @@ def record():
         _recording_thread = Thread(group=None, target=__thread_method)
         _recording_thread.start()
     else:
-        PTLogger.info("Microphone is already recording!")
+        logger.info("Microphone is already recording!")
 
 
 def is_recording():
@@ -319,11 +316,11 @@ def save(file_path, overwrite=False):
                 _temp_file_path = ""
 
             else:
-                PTLogger.info("File already exists")
+                logger.info("File already exists")
         else:
-            PTLogger.info("No recorded audio data found")
+            logger.info("No recorded audio data found")
     else:
-        PTLogger.info("Microphone is still recording!")
+        logger.info("Microphone is still recording!")
 
 
 def set_sample_rate_to_16khz():
